@@ -1,7 +1,7 @@
 #ifndef __GWEATHER_APPLET_H_
 #define __GWEATHER_APPLET_H_
 
-/* $Id: gweather-applet.h,v 1.9 2005/12/12 00:22:17 philipl Exp $ */
+/* $Id: gweather-applet.h 9555 2006-05-29 23:33:11Z philipl $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -19,9 +19,8 @@ G_BEGIN_DECLS
 
 extern void gweather_applet_create(GWeatherApplet *gw_applet);
 extern gint timeout_cb (gpointer data);
+extern gint suncalc_timeout_cb (gpointer data);
 extern void gweather_update (GWeatherApplet *applet);
-extern void gweather_info_load (const gchar *path, GWeatherApplet *applet);
-extern void gweather_info_save (const gchar *path, GWeatherApplet *applet);
 
 G_END_DECLS
 
