@@ -1,4 +1,4 @@
-/* $Id: weather-met.c,v 1.4 2006/08/07 14:05:56 davyd Exp $ */
+/* $Id: weather-met.c 10124 2007-01-05 14:02:46Z kmaraas $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -15,7 +15,7 @@
 #endif
 
 #include <ctype.h>
-#include <malloc.h>
+#include <stdlib.h>
 #include <string.h>
 #include <strings.h>
 
